Package 'pkgdown.offline'

Title: Build 'pkgdown' Websites Offline
Description: Provides support for building 'pkgdown' websites without an internet connection. Works by bundling cached dependencies and implementing drop-in replacements for key 'pkgdown' functions. Enables package documentation websites to be built in environments where internet access is unavailable or restricted. For more details on generating 'pkgdown' websites, see Wickham et al. (2025) <doi:10.32614/CRAN.package.pkgdown>.
Authors: Nan Xiao [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-0250-5673>), John Blischak [aut] (ORCID: <https://orcid.org/0000-0003-2634-9879>), Algolia, Inc. and other contributors [ctb, cph] (autocomplete.js library), Aidan Feldman [ctb, cph] (bootstrap-toc library), Zeno Rocha [ctb, cph] (clipboard.js library), Nick Williams [ctb, cph] (headroom.js library), Julian Kühnel [ctb, cph] (mark.js library), Kiro Risk [ctb, cph] (Fuse.js library), Khan Academy and other contributors [ctb, cph] (KaTeX library), The MathJax Consortium [ctb, cph] (MathJax library)
Maintainer: Nan Xiao <[email protected]>
License: MIT + file LICENSE
Version: 0.1.2
Built: 2026-05-11 09:30:09 UTC
Source: https://github.com/nanxstats/pkgdown.offline

Help Index


Build a complete pkgdown website offline

Description

Builds a pkgdown website without requiring internet connection by using cached dependencies. Detects the installed pkgdown version and applies the appropriate offline build strategy.

Usage

build_site(...)

Arguments

...

Arguments passed to pkgdown::build_site().

Value

Invisible NULL, called for side effect of building the website.

Examples

## Not run: 
pkgdown.offline::build_site(override = list(destination = tempdir()))

## End(Not run)

Clear pkgdown cache if any

Description

Removes all files from the pkgdown cache directory if it exists. This is useful when troubleshooting or when you want to force a fresh caching of pkgdown external dependencies.

Usage

clear_cache()

Value

Invisible NULL, called for side effect of clearing the cache.

Examples

## Not run: 
pkgdown.offline::clear_cache()

## End(Not run)

Initialize site infrastructure offline

Description

Sets up the necessary infrastructure for building a pkgdown site offline by copying locally cached dependencies to the pkgdown cache directory.

Usage

init_site(...)

Arguments

...

Arguments passed to pkgdown::init_site().

Value

Invisible NULL, called for side effect of initializing site resources.

Examples

## Not run: 
pkgdown.offline::init_site(override = list(destination = tempdir()))

## End(Not run)